@@ -1,4 +1,4 @@
-import platform, os, ctypes, pkg_resources
+import platform, os, ctypes, pkg_resources, sys
 import subprocess
 import numpy as np
 
@@ -309,8 +309,8 @@ def compile(filename, outputname, *flags, compiler=None, cpp = False, message= T
     #compile
     if message:
         print(f"Compile : {c_line}")
-
-    compile_result = subprocess.run(c_line.split(), capture_output=True)
+    
+    compile_result = subprocess.run(c_line.split(), stderr=subprocess.PIPE)
     if  compile_result.returncode != 0:
         try:
             print(compile_result.stderr.decode())
